@@ -1,21 +1,20 @@
 #!/bin/false
 # PODNAME: BZ::Client::XMLRPC::Parser
 # ABSTRACT: A parser for an XML-RPC response.
+# vim: softtabstop=4 tabstop=4 shiftwidth=4 ft=perl expandtab smarttab
 
 use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Parser;
-$BZ::Client::XMLRPC::Parser::VERSION = '4.4001';
+$BZ::Client::XMLRPC::Parser::VERSION = '4.4002';
 use BZ::Client::XMLRPC::Response;
 use BZ::Client::Exception;
 use XML::Parser ();
 
 sub new {
     my $class = shift;
-    my $self = { @_ };
-    bless($self, ref($class) || $class);
-    return $self
+    return bless({ @_ }, ref($class) || $class);
 }
 
 sub parse {
@@ -42,14 +41,19 @@ sub parse {
     my $chars = sub {
         my(undef, $text) = @_;
         my $current = $self->{'current'};
-        $self->error('Illegal state, no more handlers available on stack.') unless $current;
+        $self->error('Illegal state, no more handlers available on stack.')
+            unless $current;
         $current->characters($text);
     };
-    my $parser = XML::Parser->new(Handlers => {Start => $start,
-                                               End   => $end,
-                                               Char  => $chars});
+    my $parser = XML::Parser->new(
+                            Handlers => {
+                                Start => $start,
+                                End   => $end,
+                                Char  => $chars
+                            });
     $parser->parse($content);
-    die $self->{'exception'} if ($self->{'exception'});
+    die $self->{'exception'}
+        if $self->{'exception'};
     return $self->{'result'}
 }
 
@@ -60,7 +64,7 @@ sub register {
         $parent->dec_level();
     }
     $self->{'current'} = $handler;
-    push(@{$self->{'stack'}}, $current);
+    push @{$self->{'stack'}}, $current;
     $handler->init($self)
 }
 
@@ -105,7 +109,7 @@ BZ::Client::XMLRPC::Parser - A parser for an XML-RPC response.
 
 =head1 VERSION
 
-version 4.4001
+version 4.4002
 
 =head1 AUTHORS
 
