@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Response;
-$BZ::Client::XMLRPC::Response::VERSION = '4.4001';
+$BZ::Client::XMLRPC::Response::VERSION = '4.4002';
 use parent qw( BZ::Client::XMLRPC::Handler );
 use BZ::Client::XMLRPC::Value;
 use BZ::Client::Exception;
@@ -18,18 +18,22 @@ sub start {
         if ('methodResponse' ne $name) {
             $self->error("Expected methodResponse element, got $name");
         }
-    } elsif ($l == 1) {
+    }
+    elsif ($l == 1) {
         if ('fault' eq $name) {
             $self->{'in_fault'} = 1;
-        } elsif ('params' eq $name) {
+        }
+        elsif ('params' eq $name) {
             if (defined($self->{'result'})) {
                 $self->error('Multiple elements methodResponse/params found.');
             }
             $self->{'in_fault'} = 0;
-        } else {
+        }
+        else {
             $self->error("Unexpected element methodResponse/$name, expected fault|params");
         }
-    } elsif ($l == 2) {
+    }
+    elsif ($l == 2) {
         if ($self->{'in_fault'}) {
             if ('value' ne $name) {
                 $self->error("Unexpected element methodResponse/fault/$name, expected value");
@@ -46,7 +50,8 @@ sub start {
                                                                   'xmlrpc_code' => $faultCode);
             });
             $handler->start($name);
-        } else {
+        }
+        else {
             if ('param' ne $name) {
                 $self->error("Unexpected element methodResponse/params/$name, expected param");
             }
@@ -54,10 +59,12 @@ sub start {
                 $self->error('Multiple elements methodResponse/params/param found.');
             }
         }
-    } elsif ($l == 3) {
+    }
+    elsif ($l == 3) {
         if ($self->{'in_fault'}) {
             $self->error("Unexpected element $name found at level $l");
-        } else {
+        }
+        else {
             if ('value' ne $name) {
                 $self->error("Unexpected element methodResponse/params/param/$name, expected value");
             }
@@ -103,7 +110,7 @@ BZ::Client::XMLRPC::Response - Event handler for parsing an XML-RPC response.
 
 =head1 VERSION
 
-version 4.4001
+version 4.4002
 
 =head1 AUTHORS
 
