@@ -6,8 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Struct;
-$BZ::Client::XMLRPC::Struct::VERSION = '4.4001';
-use parent qw(BZ::Client::XMLRPC::Handler );
+$BZ::Client::XMLRPC::Struct::VERSION = '4.4002';
+use parent qw( BZ::Client::XMLRPC::Handler );
 
 sub init {
     my ($self, $parser) = @_;
@@ -22,29 +22,37 @@ sub start {
         if ('struct' ne $name) {
             $self->error("Expected struct element, got $name");
         }
-    } elsif ($l == 1) {
+    }
+    elsif ($l == 1) {
         if ('member' ne $name) {
             $self->error("Expected struct/member element, got $name");
         }
         $self->{'current_name'} = undef;
         $self->{'parsing_name'} = undef;
-    } elsif ($l == 2) {
+    }
+    elsif ($l == 2) {
         if ('name' eq $name) {
-            $self->error("Multiple name elements in struct/member") if defined $self->{'parsing_name'};
+            $self->error('Multiple name elements in struct/member')
+                if defined $self->{'parsing_name'};
             $self->{'parsing_name'} = q();
-        } elsif ('value' eq $name) {
+        }
+        elsif ('value' eq $name) {
             my $current_name = $self->{'current_name'};
-            $self->error("Expected struct/member/name element, got value") unless defined $current_name;
-            $self->error('Multiple value elements in struct/member, or multiple members with the same name.') if defined $self->{'result'}->{$current_name};
+            $self->error('Expected struct/member/name element, got value')
+                unless defined $current_name;
+            $self->error('Multiple value elements in struct/member, or multiple members with the same name.')
+                if defined $self->{'result'}->{$current_name};
             my $handler = BZ::Client::XMLRPC::Value->new();
             $self->parser()->register($self, $handler, sub {
                 $self->{'result'}->{$current_name} = $handler->result()
             });
             $handler->start($name);
-        } else {
+        }
+        else {
             $self->error("Expected name|value element in struct/member, got $name");
         }
-    } else {
+    }
+    else {
         $self->error("Unexpected level $l with element $name");
     }
 }
@@ -52,7 +60,7 @@ sub start {
 sub end {
     my($self,$name) = @_;
     my $l = $self->SUPER::end($name);
-    if ($l == 2  && defined($self->{'parsing_name'})) {
+    if ($l == 2 and defined($self->{'parsing_name'})) {
         $self->{'current_name'} = $self->{'parsing_name'};
     }
     return $l
@@ -61,9 +69,10 @@ sub end {
 sub characters {
     my($self, $text) = @_;
     my $l = $self->level();
-    if ($l == 3  && defined($self->{'parsing_name'})) {
+    if ($l == 3 and defined($self->{'parsing_name'})) {
         $self->{'parsing_name'} .= $text;
-    } else {
+    }
+    else {
         $self->SUPER::characters($text);
     }
 }
@@ -87,7 +96,7 @@ BZ::Client::XMLRPC::Struct - Event handler for parsing a single XML-RPC struct.
 
 =head1 VERSION
 
-version 4.4001
+version 4.4002
 
 =head1 AUTHORS
 
